@@ -12,13 +12,9 @@ class Tool(object):
         send_mail_util(self.mail_from_user, self.mail_from_user_pwd, self.mail_from_host, to_user, subject, content)
     
     def json_change(self, data):
-        json_util(data) 
+        return json_util(data)
+
 
 
 
 
-if __name__ == '__main__':
-    a = {'a':1}
-    A = Tool()
-    A.json_change(a)
-    # print(json_util(a))
