@@ -24,17 +24,14 @@ def json_util(data):
     if isinstance(data, dict):
         data = json.dumps(data)
         print("成功转换成json格式")
-        return
+        return data
     elif isinstance(data, str):
         data = json.loads(data)
         print("成功转换为dict格式")
-        return
+        return data
     else:
         print("请输入json或dict数据")
-        return
+        return "请输入json或dict数据"
 
 
-
-
-
-    
\ No newline at end of file
+ 
\ No newline at end of file
